@@ -82,7 +82,7 @@
 #define LLVM_ON_WIN32 1
 
 /* Installation prefix directory */
-#define LLVM_PREFIX "C:/conda/envs/_build/Library"
+#define LLVM_PREFIX "C:/bld/recipe_1485549435953/_b_env/Library"
 
 /* Define if we have the Intel JIT API runtime support library */
 /* #undef LLVM_USE_INTEL_JITEVENTS */
@@ -97,10 +97,10 @@
 #define LLVM_VERSION_MINOR 9
 
 /* Patch version of the LLVM API */
-#define LLVM_VERSION_PATCH 0
+#define LLVM_VERSION_PATCH 1
 
 /* LLVM version string */
-#define LLVM_VERSION_STRING "3.9.0"
+#define LLVM_VERSION_STRING "3.9.1"
 
 /* Define if we link Polly to the tools */
 /* #undef LINK_POLLY_INTO_TOOLS */
